<?php
/**
 * The header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content">
 *
 * @package Dorian
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="hfeed site">
	<a class="skip-link screen-reader-text" href="#content"><?php _e( 'Skip to content', 'dorian' ); ?></a>
	<header id="masthead" class="site-header" role="banner">
		
		<nav id="site-navigation" class="main-navigation clearfix" role="navigation">
			<div class="container">
				<div class="row">
					<div class="col-lg-12 clearfix nav-container">
						<div class="search-trigger">
							<i class="fa fa-search"></i>
						</div><!-- .search-trigger -->
						<button class="menu-toggle" aria-expanded="false"><?php _e( 'Menu', 'dorian' ); ?></button>
						<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
					</div><!-- .col-md-12 -->
					<div class="col-md-12 menu-search-container clearfix">
						<div class="close-icon-btn">
							<i class="fa fa-times"></i><span class="sr-only"><?php _e( 'Click to display search', 'dorian' ) ?></span>
						</div>
						<div class="menu-search-inner pull-right">
							<?php get_search_form(); ?>
						</div>
					</div><!-- .col-md-12 -->
				</div><!-- .row -->
			</div><!-- .container -->
		</nav><!-- #site-navigation -->
		
		<?php /* 3 header image options: 1) display header image only; 2) display header image and header text, 
			/* 3) display header text only.  Inspired by My Simone theme (https://wordpress.org/themes/simone) by  Morten Rand-Hendriksen*/
		?>
		<?php //if we have the header image but not the header text we output markup without title and tagline
			if ( ( ! display_header_text() ) && get_header_image()  ) :  
		?>
		<div class="container">
			<div class="row">
				<div class="col-md-12">
					<div class="header-image-container">
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
							<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
						</a>
					</div><!-- .header-image-container -->
				</div><!-- .col-md-12 -->
			</div><!-- .row -->
		</div><!-- .container -->
		<?php endif; // End header image check. ?>
		
		<?php //if we have both header image and header text, we output the sit-branding area with 
			// a fullwidth background image and a semi-transparent overlay  
			if ( get_header_image() && display_header_text() ) :
			echo '<div class="site-branding header-background-image" style="background-image: url(' . get_header_image() . ')">';
			echo '<div class="header-image-overlay"></div>';
			
			//if no header image and header text, we output the site-branding area without 
			//background image and without overlay 
			elseif ( ! get_header_image() && display_header_text() ): //if we don't have header image, nor header image and header text together (we only have header text)
			echo '<div class="site-branding">';
			
			endif;
		?> 
		
			<?php //if the header text is being displayed, we output it here and we 
				// also snuggle up the social menu inside the site-branding area 
			if ( display_header_text() ) :
			?>
			<div class="container">
				<div class="row">
					<div class="col-md-8 col-md-offset-2">
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
					</div><!-- .col-md-8 -->
					<?php 
					echo '<div class="col-md-12">';
						dorian_social_menu();
					echo '</div><!-- .col-md-12 -->';
					endif; 
					?>			
					
				</div><!-- .row -->
			</div><!-- .container -->
		</div><!-- .site-branding -->
		
		<?php //if we have no header text, let's add new containers for our social menu
				//outside of the site branding area
			if ( ! display_header_text() ) : 
				echo '<div class="social-icons-container">';
				echo '<div class="container">';
				echo '<div class="row">';
				echo '<div class="col-md-12">';
				dorian_social_menu();
				echo '</div><!-- .col-md-12 -->';
				echo '</div><!-- .row -->';
				echo '</div><!-- .container -->';
				echo '</div><!-- .social-icons-container -->';
			endif;
		?>
		
	</header><!-- #masthead -->

	<div class="container">
		<div id="content" class="site-content">
