<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...

	<?php if ( get_header_image() ) : ?>
	<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
		<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
	</a>
	<?php endif; // End header image check. ?>

 *
 * @package Dorian
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses dorian_header_style()
*
 */
function dorian_custom_header_setup() {
	
	add_theme_support( 'custom-header', apply_filters( 'dorian_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => '',
		'width'                  => 1280,
		'height'                 => 350,
		'flex-height'            => false,
		'wp-head-callback'       => 'dorian_header_style'
	) ) );
}
add_action( 'after_setup_theme', 'dorian_custom_header_setup' );

if ( ! function_exists( 'dorian_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see dorian_custom_header_setup().
 */
function dorian_header_style() {
	$header_text_color = get_header_textcolor();
	$header_image = get_header_image();

	// If no custom options for text are set, let's bail
	if ( $header_image && !display_header_text() ) {
		return;
	}

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden and no header image added?
		if ( empty( $header_image ) && ! display_header_text() ) :
	?>
		.site-branding {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set the text or the image, let's apply the text color 
		else :
	?>
		.site-header .site-title a,
		.site-header .header-background-image .site-title a,
		.site-header .site-description,
		.site-header .header-background-image .site-description {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // dorian_header_style